@@ -55,15 +55,19 @@ AthenaConnection <- function(aws_access_key_id = NULL,
              error = function(e) py_error(e))
   }
     
-    s3_staging_dir <- s3_staging_dir %||% get_aws_env("AWS_ATHENA_S3_STAGING_DIR")
-    
-    if(is.null(s3_staging_dir)) {stop("Please set `s3_staging_dir` either in parameter `s3_staging_dir`, environmental varaible `AWS_ATHENA_S3_STAGING_DIR`",
-                                      "or when work_group is defined in `create_work_group()`", call. = F)}
-    
+  s3_staging_dir <- s3_staging_dir %||% get_aws_env("AWS_ATHENA_S3_STAGING_DIR")
+  
+  if(is.null(s3_staging_dir)) {
+    stop("Please set `s3_staging_dir` either in parameter `s3_staging_dir`, environmental varaible `AWS_ATHENA_S3_STAGING_DIR`",
+         "or when work_group is defined in `create_work_group()`", call. = F)
+  }
+  
   info <- list(profile_name = profile_name, s3_staging = s3_staging_dir,
                dbms.name = schema_name, work_group = work_group %||% "primary",
                poll_interval = poll_interval, encryption_option = encryption_option,
-               kms_key = kms_key, expiration = aws_expiration, keyboard_interrupt = keyboard_interrupt,
+               kms_key = kms_key, expiration = aws_expiration,
+               timezone = character(),
+               keyboard_interrupt = keyboard_interrupt,
                region_name = boto3$region_name)
   
   res <- new(
